.. include:: ../README.rst
   :end-line: 16

Report issues and view source code `here <https://github.com/timoast/sinto>`__.

.. include:: release_notes.rst

.. toctree::
   :maxdepth: 1
   :hidden:

   installation
   basic_usage
